@@ -61,6 +61,12 @@ class ALSModel(Model):
         super(ALSModel, self).__init__(*args, **kwargs)
         pass
 
+    def setUserCol(self, val):
+        return self._add_param('userCol', val)
+
+    def setItemCol(self, val):
+        return self._add_param('itemCol', val)
+
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
@@ -87,6 +93,9 @@ class AftSurvivalRegression(Estimator):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
+    def setQuantileProbabilities(self, val):
+        return self._add_param('quantileProbabilities', val)
+
     def setMaxIter(self, val):
         return self._add_param('maxIter', val)
 
@@ -108,9 +117,6 @@ class AftSurvivalRegression(Estimator):
     def setL2(self, val):
         return self._add_param('l2', val)
 
-    def setQuantileProbabilities(self, val):
-        return self._add_param('quantileProbabilities', val)
-
     def setReservedCols(self, val):
         return self._add_param('reservedCols', val)
 
@@ -171,12 +177,12 @@ class BinaryClassificationTuningEvaluator(TuningEvaluator):
         super(BinaryClassificationTuningEvaluator, self).__init__(*args, **kwargs)
         pass
 
-    def setLabelCol(self, val):
-        return self._add_param('labelCol', val)
-
     def setMetricName(self, val):
         return self._add_param('metricName', val)
 
+    def setLabelCol(self, val):
+        return self._add_param('labelCol', val)
+
     def setPredictionDetailCol(self, val):
         return self._add_param('predictionDetailCol', val)
 
@@ -261,6 +267,9 @@ class Bucketizer(Transformer):
     def setCutsArray(self, val):
         return self._add_param('cutsArray', val)
 
+    def setLeftOpen(self, val):
+        return self._add_param('leftOpen', val)
+
     def setReservedCols(self, val):
         return self._add_param('reservedCols', val)
 
@@ -276,9 +285,6 @@ class Bucketizer(Transformer):
     def setDropLast(self, val):
         return self._add_param('dropLast', val)
 
-    def setLeftOpen(self, val):
-        return self._add_param('leftOpen', val)
-
     def setMLEnvironmentId(self, val):
         return self._add_param('MLEnvironmentId', val)
 
@@ -293,12 +299,12 @@ class ClusterTuningEvaluator(TuningEvaluator):
         super(ClusterTuningEvaluator, self).__init__(*args, **kwargs)
         pass
 
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
     def setMetricName(self, val):
         return self._add_param('metricName', val)
 
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
     def setLabelCol(self, val):
         return self._add_param('labelCol', val)
 
@@ -309,18 +315,18 @@ class ClusterTuningEvaluator(TuningEvaluator):
         return self._add_param('distanceType', val)
 
 
-class CsvToColumns(Transformer):
-    CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.CsvToColumns'
+class ColumnsToCsv(Transformer):
+    CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.format.ColumnsToCsv'
     OP_TYPE = 'FUNCTION'
 
     def __init__(self, *args, **kwargs):
         kwargs['CLS_NAME'] = self.CLS_NAME
         kwargs['OP_TYPE'] = self.OP_TYPE
-        super(CsvToColumns, self).__init__(*args, **kwargs)
+        super(ColumnsToCsv, self).__init__(*args, **kwargs)
         pass
 
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
+    def setCsvCol(self, val):
+        return self._add_param('csvCol', val)
 
     def setSchemaStr(self, val):
         return self._add_param('schemaStr', val)
@@ -331,8 +337,244 @@ class CsvToColumns(Transformer):
     def setReservedCols(self, val):
         return self._add_param('reservedCols', val)
 
-    def setFieldDelimiter(self, val):
-        return self._add_param('fieldDelimiter', val)
+    def setCsvFieldDelimiter(self, val):
+        return self._add_param('csvFieldDelimiter', val)
+
+    def setQuoteChar(self, val):
+        return self._add_param('quoteChar', val)
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
+
+
+class ColumnsToJson(Transformer):
+    CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.format.ColumnsToJson'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(ColumnsToJson, self).__init__(*args, **kwargs)
+        pass
+
+    def setJsonCol(self, val):
+        return self._add_param('jsonCol', val)
+
+    def setHandleInvalid(self, val):
+        return self._add_param('handleInvalid', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
+
+
+class ColumnsToKv(Transformer):
+    CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.format.ColumnsToKv'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(ColumnsToKv, self).__init__(*args, **kwargs)
+        pass
+
+    def setKvCol(self, val):
+        return self._add_param('kvCol', val)
+
+    def setHandleInvalid(self, val):
+        return self._add_param('handleInvalid', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setKvColDelimiter(self, val):
+        return self._add_param('kvColDelimiter', val)
+
+    def setKvValDelimiter(self, val):
+        return self._add_param('kvValDelimiter', val)
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
+
+
+class ColumnsToVector(Transformer):
+    CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.format.ColumnsToVector'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(ColumnsToVector, self).__init__(*args, **kwargs)
+        pass
+
+    def setVectorCol(self, val):
+        return self._add_param('vectorCol', val)
+
+    def setHandleInvalid(self, val):
+        return self._add_param('handleInvalid', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setVectorSize(self, val):
+        return self._add_param('vectorSize', val)
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
+
+
+class CsvToColumns(Transformer):
+    CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.format.CsvToColumns'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(CsvToColumns, self).__init__(*args, **kwargs)
+        pass
+
+    def setSchemaStr(self, val):
+        return self._add_param('schemaStr', val)
+
+    def setCsvCol(self, val):
+        return self._add_param('csvCol', val)
+
+    def setHandleInvalid(self, val):
+        return self._add_param('handleInvalid', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setCsvFieldDelimiter(self, val):
+        return self._add_param('csvFieldDelimiter', val)
+
+    def setQuoteChar(self, val):
+        return self._add_param('quoteChar', val)
+
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
+
+
+class CsvToJson(Transformer):
+    CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.format.CsvToJson'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(CsvToJson, self).__init__(*args, **kwargs)
+        pass
+
+    def setJsonCol(self, val):
+        return self._add_param('jsonCol', val)
+
+    def setCsvCol(self, val):
+        return self._add_param('csvCol', val)
+
+    def setSchemaStr(self, val):
+        return self._add_param('schemaStr', val)
+
+    def setHandleInvalid(self, val):
+        return self._add_param('handleInvalid', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setCsvFieldDelimiter(self, val):
+        return self._add_param('csvFieldDelimiter', val)
+
+    def setQuoteChar(self, val):
+        return self._add_param('quoteChar', val)
+
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
+
+
+class CsvToKv(Transformer):
+    CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.format.CsvToKv'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(CsvToKv, self).__init__(*args, **kwargs)
+        pass
+
+    def setKvCol(self, val):
+        return self._add_param('kvCol', val)
+
+    def setCsvCol(self, val):
+        return self._add_param('csvCol', val)
+
+    def setSchemaStr(self, val):
+        return self._add_param('schemaStr', val)
+
+    def setHandleInvalid(self, val):
+        return self._add_param('handleInvalid', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setKvColDelimiter(self, val):
+        return self._add_param('kvColDelimiter', val)
+
+    def setKvValDelimiter(self, val):
+        return self._add_param('kvValDelimiter', val)
+
+    def setCsvFieldDelimiter(self, val):
+        return self._add_param('csvFieldDelimiter', val)
+
+    def setQuoteChar(self, val):
+        return self._add_param('quoteChar', val)
+
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
+
+
+class CsvToVector(Transformer):
+    CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.format.CsvToVector'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(CsvToVector, self).__init__(*args, **kwargs)
+        pass
+
+    def setVectorCol(self, val):
+        return self._add_param('vectorCol', val)
+
+    def setCsvCol(self, val):
+        return self._add_param('csvCol', val)
+
+    def setSchemaStr(self, val):
+        return self._add_param('schemaStr', val)
+
+    def setHandleInvalid(self, val):
+        return self._add_param('handleInvalid', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setVectorSize(self, val):
+        return self._add_param('vectorSize', val)
+
+    def setCsvFieldDelimiter(self, val):
+        return self._add_param('csvFieldDelimiter', val)
 
     def setQuoteChar(self, val):
         return self._add_param('quoteChar', val)
@@ -400,29 +642,17 @@ class DecisionTreeClassifier(Estimator):
         super(DecisionTreeClassifier, self).__init__(*args, **kwargs)
         pass
 
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
     def setFeatureCols(self, val):
         return self._add_param('featureCols', val)
 
     def setLabelCol(self, val):
         return self._add_param('labelCol', val)
 
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setCategoricalCols(self, val):
-        return self._add_param('categoricalCols', val)
-
-    def setWeightCol(self, val):
-        return self._add_param('weightCol', val)
-
-    def setMaxLeaves(self, val):
-        return self._add_param('maxLeaves', val)
-
-    def setMinSampleRatioPerChild(self, val):
-        return self._add_param('minSampleRatioPerChild', val)
-
-    def setMinInfoGain(self, val):
-        return self._add_param('minInfoGain', val)
+    def setTreeType(self, val):
+        return self._add_param('treeType', val)
 
     def setMaxDepth(self, val):
         return self._add_param('maxDepth', val)
@@ -439,9 +669,6 @@ class DecisionTreeClassifier(Estimator):
     def setMaxMemoryInMB(self, val):
         return self._add_param('maxMemoryInMB', val)
 
-    def setTreeType(self, val):
-        return self._add_param('treeType', val)
-
     def setPredictionDetailCol(self, val):
         return self._add_param('predictionDetailCol', val)
 
@@ -451,6 +678,21 @@ class DecisionTreeClassifier(Estimator):
     def setMLEnvironmentId(self, val):
         return self._add_param('MLEnvironmentId', val)
 
+    def setCategoricalCols(self, val):
+        return self._add_param('categoricalCols', val)
+
+    def setWeightCol(self, val):
+        return self._add_param('weightCol', val)
+
+    def setMaxLeaves(self, val):
+        return self._add_param('maxLeaves', val)
+
+    def setMinSampleRatioPerChild(self, val):
+        return self._add_param('minSampleRatioPerChild', val)
+
+    def setMinInfoGain(self, val):
+        return self._add_param('minInfoGain', val)
+
 
 class DecisionTreeRegressionModel(Model):
     CLS_NAME = 'com.alibaba.alink.pipeline.regression.DecisionTreeRegressionModel'
@@ -485,30 +727,15 @@ class DecisionTreeRegressor(Estimator):
         super(DecisionTreeRegressor, self).__init__(*args, **kwargs)
         pass
 
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
     def setFeatureCols(self, val):
         return self._add_param('featureCols', val)
 
     def setLabelCol(self, val):
         return self._add_param('labelCol', val)
 
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setCategoricalCols(self, val):
-        return self._add_param('categoricalCols', val)
-
-    def setWeightCol(self, val):
-        return self._add_param('weightCol', val)
-
-    def setMaxLeaves(self, val):
-        return self._add_param('maxLeaves', val)
-
-    def setMinSampleRatioPerChild(self, val):
-        return self._add_param('minSampleRatioPerChild', val)
-
-    def setMinInfoGain(self, val):
-        return self._add_param('minInfoGain', val)
-
     def setMaxDepth(self, val):
         return self._add_param('maxDepth', val)
 
@@ -533,6 +760,21 @@ class DecisionTreeRegressor(Estimator):
     def setMLEnvironmentId(self, val):
         return self._add_param('MLEnvironmentId', val)
 
+    def setCategoricalCols(self, val):
+        return self._add_param('categoricalCols', val)
+
+    def setWeightCol(self, val):
+        return self._add_param('weightCol', val)
+
+    def setMaxLeaves(self, val):
+        return self._add_param('maxLeaves', val)
+
+    def setMinSampleRatioPerChild(self, val):
+        return self._add_param('minSampleRatioPerChild', val)
+
+    def setMinInfoGain(self, val):
+        return self._add_param('minInfoGain', val)
+
 
 class DocCountVectorizer(Estimator):
     CLS_NAME = 'com.alibaba.alink.pipeline.nlp.DocCountVectorizer'
@@ -547,12 +789,6 @@ class DocCountVectorizer(Estimator):
     def setSelectedCol(self, val):
         return self._add_param('selectedCol', val)
 
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
     def setMaxDF(self, val):
         return self._add_param('maxDF', val)
 
@@ -571,6 +807,12 @@ class DocCountVectorizer(Estimator):
     def setMLEnvironmentId(self, val):
         return self._add_param('MLEnvironmentId', val)
 
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
 
 class DocCountVectorizerModel(Model):
     CLS_NAME = 'com.alibaba.alink.pipeline.nlp.DocCountVectorizerModel'
@@ -608,12 +850,6 @@ class DocHashCountVectorizer(Estimator):
     def setSelectedCol(self, val):
         return self._add_param('selectedCol', val)
 
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
     def setNumFeatures(self, val):
         return self._add_param('numFeatures', val)
 
@@ -629,6 +865,12 @@ class DocHashCountVectorizer(Estimator):
     def setMLEnvironmentId(self, val):
         return self._add_param('MLEnvironmentId', val)
 
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
 
 class DocHashCountVectorizerModel(Model):
     CLS_NAME = 'com.alibaba.alink.pipeline.nlp.DocHashCountVectorizerModel'
@@ -643,15 +885,15 @@ class DocHashCountVectorizerModel(Model):
     def setSelectedCol(self, val):
         return self._add_param('selectedCol', val)
 
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
+
     def setOutputCol(self, val):
         return self._add_param('outputCol', val)
 
     def setReservedCols(self, val):
         return self._add_param('reservedCols', val)
 
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
-
 
 class FeatureHasher(Transformer):
     CLS_NAME = 'com.alibaba.alink.pipeline.feature.FeatureHasher'
@@ -727,6 +969,9 @@ class GaussianMixtureModel(Model):
         super(GaussianMixtureModel, self).__init__(*args, **kwargs)
         pass
 
+    def setVectorCol(self, val):
+        return self._add_param('vectorCol', val)
+
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
@@ -788,21 +1033,6 @@ class GbdtClassifier(Estimator):
     def setMinSumHessianPerLeaf(self, val):
         return self._add_param('minSumHessianPerLeaf', val)
 
-    def setCategoricalCols(self, val):
-        return self._add_param('categoricalCols', val)
-
-    def setWeightCol(self, val):
-        return self._add_param('weightCol', val)
-
-    def setMaxLeaves(self, val):
-        return self._add_param('maxLeaves', val)
-
-    def setMinSampleRatioPerChild(self, val):
-        return self._add_param('minSampleRatioPerChild', val)
-
-    def setMinInfoGain(self, val):
-        return self._add_param('minInfoGain', val)
-
     def setNumTrees(self, val):
         return self._add_param('numTrees', val)
 
@@ -824,6 +1054,21 @@ class GbdtClassifier(Estimator):
     def setMaxBins(self, val):
         return self._add_param('maxBins', val)
 
+    def setCategoricalCols(self, val):
+        return self._add_param('categoricalCols', val)
+
+    def setWeightCol(self, val):
+        return self._add_param('weightCol', val)
+
+    def setMaxLeaves(self, val):
+        return self._add_param('maxLeaves', val)
+
+    def setMinSampleRatioPerChild(self, val):
+        return self._add_param('minSampleRatioPerChild', val)
+
+    def setMinInfoGain(self, val):
+        return self._add_param('minInfoGain', val)
+
     def setPredictionDetailCol(self, val):
         return self._add_param('predictionDetailCol', val)
 
@@ -867,36 +1112,21 @@ class GbdtRegressor(Estimator):
         super(GbdtRegressor, self).__init__(*args, **kwargs)
         pass
 
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
     def setFeatureCols(self, val):
         return self._add_param('featureCols', val)
 
     def setLabelCol(self, val):
         return self._add_param('labelCol', val)
 
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
     def setLearningRate(self, val):
         return self._add_param('learningRate', val)
 
     def setMinSumHessianPerLeaf(self, val):
         return self._add_param('minSumHessianPerLeaf', val)
 
-    def setCategoricalCols(self, val):
-        return self._add_param('categoricalCols', val)
-
-    def setWeightCol(self, val):
-        return self._add_param('weightCol', val)
-
-    def setMaxLeaves(self, val):
-        return self._add_param('maxLeaves', val)
-
-    def setMinSampleRatioPerChild(self, val):
-        return self._add_param('minSampleRatioPerChild', val)
-
-    def setMinInfoGain(self, val):
-        return self._add_param('minInfoGain', val)
-
     def setNumTrees(self, val):
         return self._add_param('numTrees', val)
 
@@ -927,6 +1157,21 @@ class GbdtRegressor(Estimator):
     def setMLEnvironmentId(self, val):
         return self._add_param('MLEnvironmentId', val)
 
+    def setCategoricalCols(self, val):
+        return self._add_param('categoricalCols', val)
+
+    def setWeightCol(self, val):
+        return self._add_param('weightCol', val)
+
+    def setMaxLeaves(self, val):
+        return self._add_param('maxLeaves', val)
+
+    def setMinSampleRatioPerChild(self, val):
+        return self._add_param('minSampleRatioPerChild', val)
+
+    def setMinInfoGain(self, val):
+        return self._add_param('minInfoGain', val)
+
 
 class GeneralizedLinearRegression(Estimator):
     CLS_NAME = 'com.alibaba.alink.pipeline.regression.GeneralizedLinearRegression'
@@ -938,15 +1183,15 @@ class GeneralizedLinearRegression(Estimator):
         super(GeneralizedLinearRegression, self).__init__(*args, **kwargs)
         pass
 
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
     def setFeatureCols(self, val):
         return self._add_param('featureCols', val)
 
     def setLabelCol(self, val):
         return self._add_param('labelCol', val)
 
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
     def setFamily(self, val):
         return self._add_param('family', val)
 
@@ -971,15 +1216,15 @@ class GeneralizedLinearRegression(Estimator):
     def setEpsilon(self, val):
         return self._add_param('epsilon', val)
 
+    def setLinkPredResultCol(self, val):
+        return self._add_param('linkPredResultCol', val)
+
     def setWeightCol(self, val):
         return self._add_param('weightCol', val)
 
     def setMaxIter(self, val):
         return self._add_param('maxIter', val)
 
-    def setLinkPredResultCol(self, val):
-        return self._add_param('linkPredResultCol', val)
-
     def setMLEnvironmentId(self, val):
         return self._add_param('MLEnvironmentId', val)
 
@@ -1185,7 +1430,7 @@ class IsotonicRegressionModel(Model):
 
 
 class JsonToColumns(Transformer):
-    CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.JsonToColumns'
+    CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.format.JsonToColumns'
     OP_TYPE = 'FUNCTION'
 
     def __init__(self, *args, **kwargs):
@@ -1194,12 +1439,12 @@ class JsonToColumns(Transformer):
         super(JsonToColumns, self).__init__(*args, **kwargs)
         pass
 
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
-
     def setSchemaStr(self, val):
         return self._add_param('schemaStr', val)
 
+    def setJsonCol(self, val):
+        return self._add_param('jsonCol', val)
+
     def setHandleInvalid(self, val):
         return self._add_param('handleInvalid', val)
 
@@ -1210,6 +1455,102 @@ class JsonToColumns(Transformer):
         return self._add_param('MLEnvironmentId', val)
 
 
+class JsonToCsv(Transformer):
+    CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.format.JsonToCsv'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(JsonToCsv, self).__init__(*args, **kwargs)
+        pass
+
+    def setCsvCol(self, val):
+        return self._add_param('csvCol', val)
+
+    def setSchemaStr(self, val):
+        return self._add_param('schemaStr', val)
+
+    def setJsonCol(self, val):
+        return self._add_param('jsonCol', val)
+
+    def setHandleInvalid(self, val):
+        return self._add_param('handleInvalid', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setCsvFieldDelimiter(self, val):
+        return self._add_param('csvFieldDelimiter', val)
+
+    def setQuoteChar(self, val):
+        return self._add_param('quoteChar', val)
+
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
+
+
+class JsonToKv(Transformer):
+    CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.format.JsonToKv'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(JsonToKv, self).__init__(*args, **kwargs)
+        pass
+
+    def setKvCol(self, val):
+        return self._add_param('kvCol', val)
+
+    def setJsonCol(self, val):
+        return self._add_param('jsonCol', val)
+
+    def setHandleInvalid(self, val):
+        return self._add_param('handleInvalid', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setKvColDelimiter(self, val):
+        return self._add_param('kvColDelimiter', val)
+
+    def setKvValDelimiter(self, val):
+        return self._add_param('kvValDelimiter', val)
+
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
+
+
+class JsonToVector(Transformer):
+    CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.format.JsonToVector'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(JsonToVector, self).__init__(*args, **kwargs)
+        pass
+
+    def setVectorCol(self, val):
+        return self._add_param('vectorCol', val)
+
+    def setJsonCol(self, val):
+        return self._add_param('jsonCol', val)
+
+    def setHandleInvalid(self, val):
+        return self._add_param('handleInvalid', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setVectorSize(self, val):
+        return self._add_param('vectorSize', val)
+
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
+
+
 class KMeans(Estimator):
     CLS_NAME = 'com.alibaba.alink.pipeline.clustering.KMeans'
     OP_TYPE = 'FUNCTION'
@@ -1226,6 +1567,9 @@ class KMeans(Estimator):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
+    def setPredictionDistanceCol(self, val):
+        return self._add_param('predictionDistanceCol', val)
+
     def setDistanceType(self, val):
         return self._add_param('distanceType', val)
 
@@ -1244,9 +1588,6 @@ class KMeans(Estimator):
     def setEpsilon(self, val):
         return self._add_param('epsilon', val)
 
-    def setPredictionDistanceCol(self, val):
-        return self._add_param('predictionDistanceCol', val)
-
     def setPredictionDetailCol(self, val):
         return self._add_param('predictionDetailCol', val)
 
@@ -1256,353 +1597,3 @@ class KMeans(Estimator):
     def setMLEnvironmentId(self, val):
         return self._add_param('MLEnvironmentId', val)
 
-
-class KMeansModel(Model):
-    CLS_NAME = 'com.alibaba.alink.pipeline.clustering.KMeansModel'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(KMeansModel, self).__init__(*args, **kwargs)
-        pass
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setPredictionDistanceCol(self, val):
-        return self._add_param('predictionDistanceCol', val)
-
-    def setPredictionDetailCol(self, val):
-        return self._add_param('predictionDetailCol', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
-
-
-class KvToColumns(Transformer):
-    CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.KvToColumns'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(KvToColumns, self).__init__(*args, **kwargs)
-        pass
-
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
-
-    def setSchemaStr(self, val):
-        return self._add_param('schemaStr', val)
-
-    def setHandleInvalid(self, val):
-        return self._add_param('handleInvalid', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setColDelimiter(self, val):
-        return self._add_param('colDelimiter', val)
-
-    def setValDelimiter(self, val):
-        return self._add_param('valDelimiter', val)
-
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
-
-
-class LassoRegression(Estimator):
-    CLS_NAME = 'com.alibaba.alink.pipeline.regression.LassoRegression'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(LassoRegression, self).__init__(*args, **kwargs)
-        pass
-
-    def setLabelCol(self, val):
-        return self._add_param('labelCol', val)
-
-    def setLambda(self, val):
-        return self._add_param('lambda', val)
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setOptimMethod(self, val):
-        return self._add_param('optimMethod', val)
-
-    def setWithIntercept(self, val):
-        return self._add_param('withIntercept', val)
-
-    def setMaxIter(self, val):
-        return self._add_param('maxIter', val)
-
-    def setEpsilon(self, val):
-        return self._add_param('epsilon', val)
-
-    def setFeatureCols(self, val):
-        return self._add_param('featureCols', val)
-
-    def setWeightCol(self, val):
-        return self._add_param('weightCol', val)
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
-    def setStandardization(self, val):
-        return self._add_param('standardization', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
-
-
-class LassoRegressionModel(Model):
-    CLS_NAME = 'com.alibaba.alink.pipeline.regression.LassoRegressionModel'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(LassoRegressionModel, self).__init__(*args, **kwargs)
-        pass
-
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
-
-
-class Lda(Estimator):
-    CLS_NAME = 'com.alibaba.alink.pipeline.clustering.Lda'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(Lda, self).__init__(*args, **kwargs)
-        pass
-
-    def setTopicNum(self, val):
-        return self._add_param('topicNum', val)
-
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setAlpha(self, val):
-        return self._add_param('alpha', val)
-
-    def setBeta(self, val):
-        return self._add_param('beta', val)
-
-    def setMethod(self, val):
-        return self._add_param('method', val)
-
-    def setOnlineLearningOffset(self, val):
-        return self._add_param('onlineLearningOffset', val)
-
-    def setLearningDecay(self, val):
-        return self._add_param('learningDecay', val)
-
-    def setSubsamplingRate(self, val):
-        return self._add_param('subsamplingRate', val)
-
-    def setOptimizeDocConcentration(self, val):
-        return self._add_param('optimizeDocConcentration', val)
-
-    def setNumIter(self, val):
-        return self._add_param('numIter', val)
-
-    def setVocabSize(self, val):
-        return self._add_param('vocabSize', val)
-
-    def setPredictionDetailCol(self, val):
-        return self._add_param('predictionDetailCol', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
-
-
-class LdaModel(Model):
-    CLS_NAME = 'com.alibaba.alink.pipeline.clustering.LdaModel'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(LdaModel, self).__init__(*args, **kwargs)
-        pass
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setPredictionDetailCol(self, val):
-        return self._add_param('predictionDetailCol', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
-
-
-class LinearRegression(Estimator):
-    CLS_NAME = 'com.alibaba.alink.pipeline.regression.LinearRegression'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(LinearRegression, self).__init__(*args, **kwargs)
-        pass
-
-    def setLabelCol(self, val):
-        return self._add_param('labelCol', val)
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setOptimMethod(self, val):
-        return self._add_param('optimMethod', val)
-
-    def setWithIntercept(self, val):
-        return self._add_param('withIntercept', val)
-
-    def setMaxIter(self, val):
-        return self._add_param('maxIter', val)
-
-    def setEpsilon(self, val):
-        return self._add_param('epsilon', val)
-
-    def setFeatureCols(self, val):
-        return self._add_param('featureCols', val)
-
-    def setWeightCol(self, val):
-        return self._add_param('weightCol', val)
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
-    def setStandardization(self, val):
-        return self._add_param('standardization', val)
-
-    def setL1(self, val):
-        return self._add_param('l1', val)
-
-    def setL2(self, val):
-        return self._add_param('l2', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
-
-
-class LinearRegressionModel(Model):
-    CLS_NAME = 'com.alibaba.alink.pipeline.regression.LinearRegressionModel'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(LinearRegressionModel, self).__init__(*args, **kwargs)
-        pass
-
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
-
-
-class LinearSvm(Estimator):
-    CLS_NAME = 'com.alibaba.alink.pipeline.classification.LinearSvm'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(LinearSvm, self).__init__(*args, **kwargs)
-        pass
-
-    def setLabelCol(self, val):
-        return self._add_param('labelCol', val)
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setOptimMethod(self, val):
-        return self._add_param('optimMethod', val)
-
-    def setWithIntercept(self, val):
-        return self._add_param('withIntercept', val)
-
-    def setMaxIter(self, val):
-        return self._add_param('maxIter', val)
-
-    def setEpsilon(self, val):
-        return self._add_param('epsilon', val)
-
-    def setFeatureCols(self, val):
-        return self._add_param('featureCols', val)
-
-    def setWeightCol(self, val):
-        return self._add_param('weightCol', val)
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
-    def setStandardization(self, val):
-        return self._add_param('standardization', val)
-
-    def setL1(self, val):
-        return self._add_param('l1', val)
-
-    def setL2(self, val):
-        return self._add_param('l2', val)
-
-    def setPredictionDetailCol(self, val):
-        return self._add_param('predictionDetailCol', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
-
-
-class LinearSvmModel(Model):
-    CLS_NAME = 'com.alibaba.alink.pipeline.classification.LinearSvmModel'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(LinearSvmModel, self).__init__(*args, **kwargs)
-        pass
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setPredictionDetailCol(self, val):
-        return self._add_param('predictionDetailCol', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
-
