@@ -160,6 +160,154 @@ class BucketizerStreamOp(StreamOperator):
         return self._add_param('MLEnvironmentId', val)
 
 
+class ColumnsToCsvStreamOp(StreamOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.format.ColumnsToCsvStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(ColumnsToCsvStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setCsvCol(self, val):
+        return self._add_param('csvCol', val)
+
+    def setSchemaStr(self, val):
+        return self._add_param('schemaStr', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setCsvFieldDelimiter(self, val):
+        return self._add_param('csvFieldDelimiter', val)
+
+    def setQuoteChar(self, val):
+        return self._add_param('quoteChar', val)
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setHandleInvalid(self, val):
+        return self._add_param('handleInvalid', val)
+
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
+
+
+class ColumnsToJsonStreamOp(StreamOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.format.ColumnsToJsonStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(ColumnsToJsonStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setJsonCol(self, val):
+        return self._add_param('jsonCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setHandleInvalid(self, val):
+        return self._add_param('handleInvalid', val)
+
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
+
+
+class ColumnsToKvStreamOp(StreamOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.format.ColumnsToKvStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(ColumnsToKvStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setKvCol(self, val):
+        return self._add_param('kvCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setKvColDelimiter(self, val):
+        return self._add_param('kvColDelimiter', val)
+
+    def setKvValDelimiter(self, val):
+        return self._add_param('kvValDelimiter', val)
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setHandleInvalid(self, val):
+        return self._add_param('handleInvalid', val)
+
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
+
+
+class ColumnsToTripleStreamOp(StreamOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.format.ColumnsToTripleStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(ColumnsToTripleStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setTripleColValSchemaStr(self, val):
+        return self._add_param('tripleColValSchemaStr', val)
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setHandleInvalid(self, val):
+        return self._add_param('handleInvalid', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
+
+
+class ColumnsToVectorStreamOp(StreamOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.format.ColumnsToVectorStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(ColumnsToVectorStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setVectorCol(self, val):
+        return self._add_param('vectorCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setVectorSize(self, val):
+        return self._add_param('vectorSize', val)
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setHandleInvalid(self, val):
+        return self._add_param('handleInvalid', val)
+
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
+
+
 class CsvSinkStreamOp(BaseSinkStreamOp):
     CLS_NAME = 'com.alibaba.alink.operator.stream.sink.CsvSinkStreamOp'
     OP_TYPE = 'SINK'
@@ -243,12 +391,12 @@ class CsvToColumnsStreamOp(StreamOperator):
     def setSchemaStr(self, val):
         return self._add_param('schemaStr', val)
 
-    def setHandleInvalid(self, val):
-        return self._add_param('handleInvalid', val)
-
     def setReservedCols(self, val):
         return self._add_param('reservedCols', val)
 
+    def setHandleInvalidMethod(self, val):
+        return self._add_param('handleInvalidMethod', val)
+
     def setFieldDelimiter(self, val):
         return self._add_param('fieldDelimiter', val)
 
@@ -259,6 +407,175 @@ class CsvToColumnsStreamOp(StreamOperator):
         return self._add_param('MLEnvironmentId', val)
 
 
+class CsvToColumnsStreamOp(StreamOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.format.CsvToColumnsStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(CsvToColumnsStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setSchemaStr(self, val):
+        return self._add_param('schemaStr', val)
+
+    def setCsvCol(self, val):
+        return self._add_param('csvCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setCsvFieldDelimiter(self, val):
+        return self._add_param('csvFieldDelimiter', val)
+
+    def setQuoteChar(self, val):
+        return self._add_param('quoteChar', val)
+
+    def setHandleInvalid(self, val):
+        return self._add_param('handleInvalid', val)
+
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
+
+
+class CsvToJsonStreamOp(StreamOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.format.CsvToJsonStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(CsvToJsonStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setJsonCol(self, val):
+        return self._add_param('jsonCol', val)
+
+    def setCsvCol(self, val):
+        return self._add_param('csvCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setCsvFieldDelimiter(self, val):
+        return self._add_param('csvFieldDelimiter', val)
+
+    def setQuoteChar(self, val):
+        return self._add_param('quoteChar', val)
+
+    def setHandleInvalid(self, val):
+        return self._add_param('handleInvalid', val)
+
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
+
+
+class CsvToKvStreamOp(StreamOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.format.CsvToKvStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(CsvToKvStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setKvCol(self, val):
+        return self._add_param('kvCol', val)
+
+    def setCsvCol(self, val):
+        return self._add_param('csvCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setKvColDelimiter(self, val):
+        return self._add_param('kvColDelimiter', val)
+
+    def setKvValDelimiter(self, val):
+        return self._add_param('kvValDelimiter', val)
+
+    def setCsvFieldDelimiter(self, val):
+        return self._add_param('csvFieldDelimiter', val)
+
+    def setQuoteChar(self, val):
+        return self._add_param('quoteChar', val)
+
+    def setHandleInvalid(self, val):
+        return self._add_param('handleInvalid', val)
+
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
+
+
+class CsvToTripleStreamOp(StreamOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.format.CsvToTripleStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(CsvToTripleStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setCsvCol(self, val):
+        return self._add_param('csvCol', val)
+
+    def setTripleColValSchemaStr(self, val):
+        return self._add_param('tripleColValSchemaStr', val)
+
+    def setCsvFieldDelimiter(self, val):
+        return self._add_param('csvFieldDelimiter', val)
+
+    def setQuoteChar(self, val):
+        return self._add_param('quoteChar', val)
+
+    def setHandleInvalid(self, val):
+        return self._add_param('handleInvalid', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
+
+
+class CsvToVectorStreamOp(StreamOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.format.CsvToVectorStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(CsvToVectorStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setVectorCol(self, val):
+        return self._add_param('vectorCol', val)
+
+    def setCsvCol(self, val):
+        return self._add_param('csvCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setVectorSize(self, val):
+        return self._add_param('vectorSize', val)
+
+    def setCsvFieldDelimiter(self, val):
+        return self._add_param('csvFieldDelimiter', val)
+
+    def setQuoteChar(self, val):
+        return self._add_param('quoteChar', val)
+
+    def setHandleInvalid(self, val):
+        return self._add_param('handleInvalid', val)
+
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
+
+
 class DCTStreamOp(StreamOperator):
     CLS_NAME = 'com.alibaba.alink.operator.stream.feature.DCTStreamOp'
     OP_TYPE = 'FUNCTION'
@@ -640,6 +957,35 @@ class GmmPredictStreamOp(BaseModelStreamOp):
         return self._add_param('MLEnvironmentId', val)
 
 
+class HiveSourceStreamOp(StreamOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.source.HiveSourceStreamOp'
+    OP_TYPE = 'SOURCE'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(HiveSourceStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setHiveConfDir(self, val):
+        return self._add_param('hiveConfDir', val)
+
+    def setHiveVersion(self, val):
+        return self._add_param('hiveVersion', val)
+
+    def setDbName(self, val):
+        return self._add_param('dbName', val)
+
+    def setInputTableName(self, val):
+        return self._add_param('inputTableName', val)
+
+    def setPartitions(self, val):
+        return self._add_param('partitions', val)
+
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
+
+
 class ImputerPredictStreamOp(BaseModelStreamOp):
     CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.ImputerPredictStreamOp'
     OP_TYPE = 'FUNCTION'
@@ -730,6 +1076,125 @@ class JsonToColumnsStreamOp(StreamOperator):
     def setSchemaStr(self, val):
         return self._add_param('schemaStr', val)
 
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setHandleInvalidMethod(self, val):
+        return self._add_param('handleInvalidMethod', val)
+
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
+
+
+class JsonToColumnsStreamOp(StreamOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.format.JsonToColumnsStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(JsonToColumnsStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setSchemaStr(self, val):
+        return self._add_param('schemaStr', val)
+
+    def setJsonCol(self, val):
+        return self._add_param('jsonCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setHandleInvalid(self, val):
+        return self._add_param('handleInvalid', val)
+
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
+
+
+class JsonToCsvStreamOp(StreamOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.format.JsonToCsvStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(JsonToCsvStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setCsvCol(self, val):
+        return self._add_param('csvCol', val)
+
+    def setSchemaStr(self, val):
+        return self._add_param('schemaStr', val)
+
+    def setJsonCol(self, val):
+        return self._add_param('jsonCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setCsvFieldDelimiter(self, val):
+        return self._add_param('csvFieldDelimiter', val)
+
+    def setQuoteChar(self, val):
+        return self._add_param('quoteChar', val)
+
+    def setHandleInvalid(self, val):
+        return self._add_param('handleInvalid', val)
+
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
+
+
+class JsonToKvStreamOp(StreamOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.format.JsonToKvStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(JsonToKvStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setKvCol(self, val):
+        return self._add_param('kvCol', val)
+
+    def setJsonCol(self, val):
+        return self._add_param('jsonCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setKvColDelimiter(self, val):
+        return self._add_param('kvColDelimiter', val)
+
+    def setKvValDelimiter(self, val):
+        return self._add_param('kvValDelimiter', val)
+
+    def setHandleInvalid(self, val):
+        return self._add_param('handleInvalid', val)
+
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
+
+
+class JsonToTripleStreamOp(StreamOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.format.JsonToTripleStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(JsonToTripleStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setJsonCol(self, val):
+        return self._add_param('jsonCol', val)
+
+    def setTripleColValSchemaStr(self, val):
+        return self._add_param('tripleColValSchemaStr', val)
+
     def setHandleInvalid(self, val):
         return self._add_param('handleInvalid', val)
 
@@ -740,6 +1205,35 @@ class JsonToColumnsStreamOp(StreamOperator):
         return self._add_param('MLEnvironmentId', val)
 
 
+class JsonToVectorStreamOp(StreamOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.format.JsonToVectorStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(JsonToVectorStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setVectorCol(self, val):
+        return self._add_param('vectorCol', val)
+
+    def setJsonCol(self, val):
+        return self._add_param('jsonCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setVectorSize(self, val):
+        return self._add_param('vectorSize', val)
+
+    def setHandleInvalid(self, val):
+        return self._add_param('handleInvalid', val)
+
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
+
+
 class JsonValueStreamOp(StreamOperator):
     CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.JsonValueStreamOp'
     OP_TYPE = 'FUNCTION'
@@ -887,434 +1381,3 @@ class Kafka011SinkStreamOp(BaseSinkStreamOp):
     def setMLEnvironmentId(self, val):
         return self._add_param('MLEnvironmentId', val)
 
-
-class Kafka011SourceStreamOp(StreamOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.source.Kafka011SourceStreamOp'
-    OP_TYPE = 'SOURCE'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(Kafka011SourceStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setBootstrapServers(self, val):
-        return self._add_param('bootstrapServers', val)
-
-    def setGroupId(self, val):
-        return self._add_param('groupId', val)
-
-    def setStartupMode(self, val):
-        return self._add_param('startupMode', val)
-
-    def setTopic(self, val):
-        return self._add_param('topic', val)
-
-    def setTopicPattern(self, val):
-        return self._add_param('topicPattern', val)
-
-    def setStartTime(self, val):
-        return self._add_param('startTime', val)
-
-    def setProperties(self, val):
-        return self._add_param('properties', val)
-
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
-
-
-class KafkaSinkStreamOp(BaseSinkStreamOp):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.sink.KafkaSinkStreamOp'
-    OP_TYPE = 'SINK'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(KafkaSinkStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setBootstrapServers(self, val):
-        return self._add_param('bootstrapServers', val)
-
-    def setTopic(self, val):
-        return self._add_param('topic', val)
-
-    def setDataFormat(self, val):
-        return self._add_param('dataFormat', val)
-
-    def setFieldDelimiter(self, val):
-        return self._add_param('fieldDelimiter', val)
-
-    def setProperties(self, val):
-        return self._add_param('properties', val)
-
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
-
-
-class KafkaSourceStreamOp(StreamOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.source.KafkaSourceStreamOp'
-    OP_TYPE = 'SOURCE'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(KafkaSourceStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setBootstrapServers(self, val):
-        return self._add_param('bootstrapServers', val)
-
-    def setGroupId(self, val):
-        return self._add_param('groupId', val)
-
-    def setStartupMode(self, val):
-        return self._add_param('startupMode', val)
-
-    def setTopic(self, val):
-        return self._add_param('topic', val)
-
-    def setTopicPattern(self, val):
-        return self._add_param('topicPattern', val)
-
-    def setStartTime(self, val):
-        return self._add_param('startTime', val)
-
-    def setProperties(self, val):
-        return self._add_param('properties', val)
-
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
-
-
-class KvToColumnsStreamOp(StreamOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.KvToColumnsStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(KvToColumnsStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
-
-    def setSchemaStr(self, val):
-        return self._add_param('schemaStr', val)
-
-    def setHandleInvalid(self, val):
-        return self._add_param('handleInvalid', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setColDelimiter(self, val):
-        return self._add_param('colDelimiter', val)
-
-    def setValDelimiter(self, val):
-        return self._add_param('valDelimiter', val)
-
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
-
-
-class LassoRegPredictStreamOp(BaseModelStreamOp):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.regression.LassoRegPredictStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(LassoRegPredictStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
-
-
-class LibSvmSinkStreamOp(BaseSinkStreamOp):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.sink.LibSvmSinkStreamOp'
-    OP_TYPE = 'SINK'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(LibSvmSinkStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setFilePath(self, val):
-        return self._add_param('filePath', val)
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
-    def setLabelCol(self, val):
-        return self._add_param('labelCol', val)
-
-    def setOverwriteSink(self, val):
-        return self._add_param('overwriteSink', val)
-
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
-
-
-class LibSvmSourceStreamOp(StreamOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.source.LibSvmSourceStreamOp'
-    OP_TYPE = 'SOURCE'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(LibSvmSourceStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setFilePath(self, val):
-        return self._add_param('filePath', val)
-
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
-
-
-class LinearRegPredictStreamOp(BaseModelStreamOp):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.regression.LinearRegPredictStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(LinearRegPredictStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
-
-
-class LinearSvmPredictStreamOp(BaseModelStreamOp):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.classification.LinearSvmPredictStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(LinearSvmPredictStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setPredictionDetailCol(self, val):
-        return self._add_param('predictionDetailCol', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
-
-
-class LogisticRegressionPredictStreamOp(BaseModelStreamOp):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.classification.LogisticRegressionPredictStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(LogisticRegressionPredictStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setPredictionDetailCol(self, val):
-        return self._add_param('predictionDetailCol', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
-
-
-class MaxAbsScalerPredictStreamOp(BaseModelStreamOp):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.MaxAbsScalerPredictStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(MaxAbsScalerPredictStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setSelectedCols(self, val):
-        return self._add_param('selectedCols', val)
-
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
-
-
-class MinMaxScalerPredictStreamOp(BaseModelStreamOp):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.MinMaxScalerPredictStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(MinMaxScalerPredictStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setSelectedCols(self, val):
-        return self._add_param('selectedCols', val)
-
-    def setMin(self, val):
-        return self._add_param('min', val)
-
-    def setMax(self, val):
-        return self._add_param('max', val)
-
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
-
-
-class MultiStringIndexerPredictStreamOp(BaseModelStreamOp):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.MultiStringIndexerPredictStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(MultiStringIndexerPredictStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setSelectedCols(self, val):
-        return self._add_param('selectedCols', val)
-
-    def setHandleInvalid(self, val):
-        return self._add_param('handleInvalid', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setOutputCols(self, val):
-        return self._add_param('outputCols', val)
-
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
-
-
-class MultilayerPerceptronPredictStreamOp(BaseModelStreamOp):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.classification.MultilayerPerceptronPredictStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(MultilayerPerceptronPredictStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setPredictionDetailCol(self, val):
-        return self._add_param('predictionDetailCol', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
-
-
-class MySqlSinkStreamOp(BaseSinkStreamOp):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.sink.MySqlSinkStreamOp'
-    OP_TYPE = 'SINK'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(MySqlSinkStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setDbName(self, val):
-        return self._add_param('dbName', val)
-
-    def setIp(self, val):
-        return self._add_param('ip', val)
-
-    def setPassword(self, val):
-        return self._add_param('password', val)
-
-    def setPort(self, val):
-        return self._add_param('port', val)
-
-    def setUsername(self, val):
-        return self._add_param('username', val)
-
-    def setOutputTableName(self, val):
-        return self._add_param('outputTableName', val)
-
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
-
-
-class MySqlSourceStreamOp(StreamOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.source.MySqlSourceStreamOp'
-    OP_TYPE = 'SOURCE'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(MySqlSourceStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setDbName(self, val):
-        return self._add_param('dbName', val)
-
-    def setIp(self, val):
-        return self._add_param('ip', val)
-
-    def setPassword(self, val):
-        return self._add_param('password', val)
-
-    def setPort(self, val):
-        return self._add_param('port', val)
-
-    def setUsername(self, val):
-        return self._add_param('username', val)
-
-    def setInputTableName(self, val):
-        return self._add_param('inputTableName', val)
-
-    def setSchemaStr(self, val):
-        return self._add_param('schemaStr', val)
-
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
-
